apply_total

Function apply_total 

pub fn apply_total(input: &EagerTensor) -> Result<Vec<EagerTensor>>
Run Df64Total on an eagerly held external tensor.

Errors

Returns tenferro_runtime::Error::RuntimeStateSource when the contribution’s module cannot be registered, or when the operation cannot be prepared or executed for this input.

Examples

use tenferro_ad::extension::ExtensionOp;
use tenferro_df64_proof::extension::{module, Df64Total};

assert_eq!(<Df64Total as ExtensionOp>::input_count(&Df64Total), 1);
assert!(module().is_ok());