module

Function module 

pub fn module() -> Result<Arc<dyn ExtensionModule>, RuntimeConfigError>
The module a downstream application installs to enable Df64Total.

Errors

Returns an error when the CPU runtime engine identifier is unavailable in this process.

Examples

use tenferro_df64_proof::extension::module;

assert!(module().is_ok());