pub struct Df64Add;Expand description
The external contribution’s addition operation.
The operation is a type in the crate that owns the scalar, so tenferro’s kernels are instantiated once per element type and operation rather than once per call site.
Examples
use tenferro_df64_proof::{Df64, Df64Add};
use tenferro_cpu::BinaryScalarOp;
let sum = <Df64Add as BinaryScalarOp<Df64>>::apply(
Df64::from_f64(1.0),
Df64::from_f64(2.0),
);
assert_eq!(sum, Df64::from_f64(3.0));Trait Implementations